@@ -61,7 +61,7 @@ _specific_fitters = [
            {'__type__': 'feature_extraction.text.HashingVectorizer',
             'analyzer': 'char_wb',
             'n_features': 8192,
-            'ngram_range': [7, 7],
+            'ngram_range': (7, 7),
             'alternate_sign': False}],
           ['classify',
            {'__type__': 'custom.LowMemoryMultinomialNB',
